#! /usr/bin/env python3

# above is the shebang, which tells machine to use python to run this file
# below is a *module docstring*, telling us what this file is and how to use

"""
This file contains a basic script for counting word frequencies in a text file.
It is written in Python 3 according to the PEP8 style guide. It is not (yet)
configured for command-line use, because paths to text are hardcoded in and
cannot be easily changed. Right now, you need to edit the script itself to
point to a text file for processing. So, to use this script, edit it so that it
points to a text file, and then from the command line (inside digizeit dir) do:

```
> ./scripts/wordcount.py

# or

> python3 ./scripts/wordcount.py
```

It works on any plain text, for example, the following file, which is plaintext
of Lewis Carroll's  Alice's Adventures in Wonderland, found at:
https://www.gutenberg.org/files/11/11-0.txt
"""

# import a tool that counts occurrences of things in python
from collections import Counter


# create a function -- a chunk of code that can be *called* multiple times
def wordcount(filepath):
    """
    This function, called wordcount, takes one argument, `filepath`,
    which is a path to plaintext data.

    It returns a Counter, with word frequencies in this filepath
    """
    # open the file (like double clicking on it)
    raw_text = open(filepath).read()
    # print the first 500 characters to screen ("\n" is newline)
    print(f"Raw data:\n\n{raw_text[:500]}\n\n")
    # make everything lowercase (i.e. normalise)
    lowered = raw_text.lower()
    # split text on spaces. is this reliable?
    wordlist = lowered.split(' ')
    # loop over each word, remove those that are not alphanumeric
    cleaned = [word for word in wordlist if word.strip().isalnum()]
    # perform the counting using the Counter class
    counted = Counter(cleaned)
    # print top 10 most frequent
    print("Counts:\n\n", counted.most_common(10), "\n\n")
    # return the wordcount data to us after we call this function
    return counted


# all we have done so far is *define* a function ...
# we haven't yet *called* it (i.e. run it). do it like this:
wordcounts = wordcount("./data/alice.txt")
# have a look at what is inside
print(wordcounts)
# get count for a particular word
wordcounts["test"]
# show the 10 most common words
wordcounts.most_common(10)

# store the results of the analysis in results.txt
with open("results.csv", "w") as results_file:
    # loop over the words starting with most frequent
    # or, we could use sorted(wordcounts.items()) to alphabetise
    for word, count in wordcounts.most_common():
        # write the word and count to file, separated by a tab
        results_file.write(f"{word}\t{count}\n")
